@@ -1,19 +1,13 @@
-from django import forms
-from django.conf import settings
-from django.utils.translation import gettext_lazy as _
 from django.contrib import admin
-from django.contrib.auth.models import User, Group
 from threaded_messages.models import *
 
 
-
-
 class MessageAdmin(admin.ModelAdmin):
-    list_display = ('sender', 'sent_at','body')
+    list_display = ('sender', 'sent_at', 'body')
     ordering = ('-sent_at',)
     search_fields = ('body', 'sender__first_name',
                      'sender__last_name', 'sender__username')
-    raw_id_fields = ('sender',)
+    raw_id_fields = ('sender', 'parent_msg')
     readonly_fields = ('subject',)
 
     def subject(self, msg):
